@@ -215,7 +215,6 @@ object is stored.
 import binascii
 import copy
 import datetime
-import warnings
 
 from keystoneauth1 import access
 from keystoneauth1 import adapter
@@ -309,12 +308,6 @@ class BaseAuthProtocol(object):
                                    perform.
     """
 
-    # NOTE(jamielennox): Default to True and remove in Queens. This is a
-    # compatibility flag to allow passing **kwargs to fetch_token(). This
-    # is basically to allow compatibility with keystone's override. We will
-    # assume all subclasses are ok with this being True in the Queens release.
-    kwargs_to_fetch_token = False
-
     def __init__(self,
                  app,
                  log=_LOG,
@@ -436,14 +429,7 @@ class BaseAuthProtocol(object):
         # NOTE(edmondsw): strip the token to remove any whitespace that may
         # have been passed along in the header per bug 1689468
         token = token.strip()
-        if self.kwargs_to_fetch_token:
-            data = self.fetch_token(token, **kwargs)
-        else:
-            m = _('Implementations of auth_token must set '
-                  'kwargs_to_fetch_token this will be the required and '
-                  'assumed in Queens.')
-            warnings.warn(m)
-            data = self.fetch_token(token)
+        data = self.fetch_token(token, **kwargs)
 
         try:
             return data, access.create(body=data, auth_token=token)
@@ -549,8 +535,6 @@ class AuthProtocol(BaseAuthProtocol):
     _SIGNING_CERT_FILE_NAME = 'signing_cert.pem'
     _SIGNING_CA_FILE_NAME = 'cacert.pem'
 
-    kwargs_to_fetch_token = True
-
     def __init__(self, app, conf):
         log = logging.getLogger(conf.get('log_name', __name__))
         log.info('Starting Keystone auth_token middleware')
@@ -559,6 +543,8 @@ class AuthProtocol(BaseAuthProtocol):
                                    _base.AUTHTOKEN_GROUP,
                                    list_opts(),
                                    conf)
+        if self._conf.oslo_conf_obj != cfg.CONF:
+            oslo_cache.configure(self._conf.oslo_conf_obj)
 
         token_roles_required = self._conf.get('service_token_roles_required')
 
@@ -776,7 +762,8 @@ class AuthProtocol(BaseAuthProtocol):
                 ksm_exceptions.RevocationListError,
                 ksm_exceptions.ServiceError) as e:
             self.log.critical('Unable to validate token: %s', e)
-            raise webob.exc.HTTPServiceUnavailable()
+            raise webob.exc.HTTPServiceUnavailable(
+                'The Keystone service is temporarily unavailable.')
         except ksm_exceptions.InvalidToken:
             self.log.debug('Token validation failure.', exc_info=True)
             if token_hashes:
@@ -957,9 +944,8 @@ class AuthProtocol(BaseAuthProtocol):
 
     def _create_oslo_cache(self):
         # having this as a function makes test mocking easier
-        conf = cfg.CONF
         region = oslo_cache.create_region()
-        oslo_cache.configure_cache_region(conf, region)
+        oslo_cache.configure_cache_region(self._conf.oslo_conf_obj, region)
         return region
 
     def _token_cache_factory(self):
